@@ -35,11 +35,9 @@ struct _AlsaStreamControlPrivate
 
 static void alsa_element_interface_init    (AlsaElementInterface   *iface);
 
-static void alsa_stream_control_class_init (AlsaStreamControlClass *klass);
-static void alsa_stream_control_init       (AlsaStreamControl      *control);
-
 G_DEFINE_ABSTRACT_TYPE_WITH_CODE (AlsaStreamControl, alsa_stream_control,
                                   MATE_MIXER_TYPE_STREAM_CONTROL,
+                                  G_ADD_PRIVATE(AlsaStreamControl)
                                   G_IMPLEMENT_INTERFACE (ALSA_TYPE_ELEMENT,
                                                          alsa_element_interface_init))
 
@@ -135,16 +133,12 @@ alsa_stream_control_class_init (AlsaStreamControlClass *klass)
     control_class->get_max_volume       = alsa_stream_control_get_max_volume;
     control_class->get_normal_volume    = alsa_stream_control_get_normal_volume;
     control_class->get_base_volume      = alsa_stream_control_get_base_volume;
-
-    g_type_class_add_private (G_OBJECT_CLASS (klass), sizeof (AlsaStreamControlPrivate));
 }
 
 static void
 alsa_stream_control_init (AlsaStreamControl *control)
 {
-    control->priv = G_TYPE_INSTANCE_GET_PRIVATE (control,
-                                                 ALSA_TYPE_STREAM_CONTROL,
-                                                 AlsaStreamControlPrivate);
+    control->priv = alsa_stream_control_get_instance_private (control);
 }
 
 AlsaControlData *
@@ -402,7 +396,7 @@ alsa_stream_control_has_channel_position (MateMixerStreamControl  *mmsc,
 
     control = ALSA_STREAM_CONTROL (mmsc);
 
-    if MATE_MIXER_CHANNEL_MASK_HAS_CHANNEL (control->priv->channel_mask, position)
+    if (MATE_MIXER_CHANNEL_MASK_HAS_CHANNEL (control->priv->channel_mask, position))
         return TRUE;
     else
         return FALSE;
@@ -461,7 +455,7 @@ alsa_stream_control_set_channel_volume (MateMixerStreamControl *mmsc, guint chan
 
         /* Convert channel index to ALSA channel position and make sure it is valid */
         snd_mixer_selem_channel_id_t c = alsa_channel_map_to[control->priv->data.c[channel]];
-        if G_UNLIKELY (c == SND_MIXER_SCHN_UNKNOWN) {
+        if (G_UNLIKELY (c == SND_MIXER_SCHN_UNKNOWN)) {
             g_warn_if_reached ();
             return FALSE;
         }
@@ -649,24 +643,32 @@ alsa_stream_control_set_fade (MateMixerStreamControl *mmsc, gfloat fade)
 static guint
 alsa_stream_control_get_min_volume (MateMixerStreamControl *mmsc)
 {
+    g_return_val_if_fail (ALSA_IS_STREAM_CONTROL (mmsc), 0);
+
     return ALSA_STREAM_CONTROL (mmsc)->priv->data.min;
 }
 
 static guint
 alsa_stream_control_get_max_volume (MateMixerStreamControl *mmsc)
 {
+    g_return_val_if_fail (ALSA_IS_STREAM_CONTROL (mmsc), 0);
+
     return ALSA_STREAM_CONTROL (mmsc)->priv->data.max;
 }
 
 static guint
 alsa_stream_control_get_normal_volume (MateMixerStreamControl *mmsc)
 {
+    g_return_val_if_fail (ALSA_IS_STREAM_CONTROL (mmsc), 0);
+
     return ALSA_STREAM_CONTROL (mmsc)->priv->data.max;
 }
 
 static guint
 alsa_stream_control_get_base_volume (MateMixerStreamControl *mmsc)
 {
+    g_return_val_if_fail (ALSA_IS_STREAM_CONTROL (mmsc), 0);
+
     return ALSA_STREAM_CONTROL (mmsc)->priv->data.max;
 }
 
@@ -680,11 +682,11 @@ control_data_get_average_left_right (AlsaControlData *data, guint *left, guint *
     guint channel;
 
     for (channel = 0; channel < data->channels; channel++)
-        if MATE_MIXER_IS_LEFT_CHANNEL (data->c[channel]) {
+        if (MATE_MIXER_IS_LEFT_CHANNEL (data->c[channel])) {
             l += data->v[channel];
             nl++;
         }
-        else if MATE_MIXER_IS_RIGHT_CHANNEL (data->c[channel]) {
+        else if (MATE_MIXER_IS_RIGHT_CHANNEL (data->c[channel])) {
             r += data->v[channel];
             nr++;
         }
@@ -703,11 +705,11 @@ control_data_get_average_front_back (AlsaControlData *data, guint *front, guint
     guint channel;
 
     for (channel = 0; channel < data->channels; channel++)
-        if MATE_MIXER_IS_FRONT_CHANNEL (data->c[channel]) {
+        if (MATE_MIXER_IS_FRONT_CHANNEL (data->c[channel])) {
             f += data->v[channel];
             nf++;
         }
-        else if MATE_MIXER_IS_BACK_CHANNEL (data->c[channel]) {
+        else if (MATE_MIXER_IS_BACK_CHANNEL (data->c[channel])) {
             b += data->v[channel];
             nb++;
         }
