@@ -61,7 +61,7 @@ static void oss_backend_finalize       (GObject         *object);
 
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunused-function"
-G_DEFINE_DYNAMIC_TYPE (OssBackend, oss_backend, MATE_MIXER_TYPE_BACKEND)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (OssBackend, oss_backend, MATE_MIXER_TYPE_BACKEND, 0, G_ADD_PRIVATE (OssBackend))
 #pragma clang diagnostic pop
 
 static gboolean     oss_backend_open             (MateMixerBackend *backend);
@@ -142,8 +142,6 @@ oss_backend_class_init (OssBackendClass *klass)
     backend_class->close        = oss_backend_close;
     backend_class->list_devices = oss_backend_list_devices;
     backend_class->list_streams = oss_backend_list_streams;
-
-    g_type_class_add_private (object_class, sizeof (OssBackendPrivate));
 }
 
 /* Called in the code generated by G_DEFINE_DYNAMIC_TYPE() */
@@ -155,9 +153,7 @@ oss_backend_class_finalize (OssBackendClass *klass)
 static void
 oss_backend_init (OssBackend *oss)
 {
-    oss->priv = G_TYPE_INSTANCE_GET_PRIVATE (oss,
-                                             OSS_TYPE_BACKEND,
-                                             OssBackendPrivate);
+    oss->priv = oss_backend_get_instance_private (oss);
 
     oss->priv->devices_paths = g_hash_table_new_full (g_str_hash,
                                                       g_str_equal,
@@ -362,7 +358,7 @@ read_device (OssBackend *oss, const gchar *path, gboolean *added)
 
     close (fd);
 
-    if G_LIKELY (device != NULL) {
+    if (G_LIKELY (device != NULL)) {
         *added = oss_device_open (device);
         if (*added == TRUE)
             add_device (oss, device);
@@ -595,7 +591,7 @@ get_default_device (OssBackend *oss)
     item = g_list_find_custom (oss->priv->devices,
                                oss->priv->default_device,
                                compare_device_path);
-    if G_LIKELY (item != NULL)
+    if (G_LIKELY (item != NULL))
         return OSS_DEVICE (item->data);
 
     return NULL;
